ChunkedBlob

Struct ChunkedBlob 

struct ChunkedBlob<BS> {
    blob_service: BS,
    chunks: Vec<(u64, u64, B3Digest)>,
}
Holds a list of blake3 digests for individual chunks (and their sizes). Is able to construct a Reader that seeked to a certain offset, which is useful to construct a BlobReader (that implements AsyncSeek).

  • the current chunk index, and a Custor<Vec<u8>> holding the data of that chunk.

Fields

blob_service: BSchunks: Vec<(u64, u64, B3Digest)>

Implementations

Source

impl<BS> ChunkedBlob<BS>
where BS: BlobService + Clone + 'static,

fn from_iter( chunks_it: impl Iterator<Item = (B3Digest, u64)>, blob_service: BS, ) -> Self

Constructs Self from a list of blake3 digests of chunks and their sizes, and a reference to a blob service. Initializing it with an empty list is disallowed.

fn blob_length(&self) -> u64

Returns the length of the blob.

fn get_chunk_idx_for_position(&self, pos: u64) -> Option<usize>

For a given position pos, return the chunk containing the data. In case this would range outside the blob, None is returned.

fn reader_skipped_offset( &self, offset: u64, ) -> Box<dyn AsyncRead + Send + Unpin>

Returns a stream of bytes of the data in that blob. It internally assembles a stream reading from each chunk (skipping over chunks containing irrelevant data). From the first relevant chunk, the irrelevant bytes are skipped too. The returned boxed thing does not implement AsyncSeek on its own, but ChunkedReader does.