MockBlobService

Struct MockBlobService 

pub struct MockBlobService {
    BlobService_expectations: MockBlobService_BlobService,
}
The base trait all BlobService services need to implement. It provides functions to check whether a given blob exists, a way to read (and seek) a blob, and a method to create a blobwriter handle, which will implement a writer interface, and also provides a close function, to finalize a blob and get its digest.

Fields

BlobService_expectations: MockBlobService_BlobService

Implementations

Source

impl MockBlobService

pub fn checkpoint(&mut self)

Validate that all current expectations for all methods have been satisfied, and discard them.

pub fn new() -> Self

Create a new mock object with no expectations.

This method will not be generated if the real struct already has a new method. However, it will be generated if the struct implements a trait with a new method. The trait’s new method can still be called like <MockX as TraitY>::new

Source

impl MockBlobService

pub fn expect_has(&mut self) -> &mut Expectation

Create an Expectation for mocking the has method

pub fn expect_open_read(&mut self) -> &mut Expectation

Create an Expectation for mocking the open_read method

pub fn expect_open_write(&mut self) -> &mut Expectation

Create an Expectation for mocking the open_write method

pub fn expect_chunks(&mut self) -> &mut Expectation

Create an Expectation for mocking the chunks method