pub struct BigtableDirectoryService {
instance_name: String,
client: BigTable,
params: BigtableParameters,
}cloud only.Expand description
Provides a DirectoryService implementation using Bigtable as an underlying K/V store.
Data format
We use Bigtable as a plain K/V store. The row key is the digest of the directory, in hexlower. Inside the row, we currently have a single column/cell, again using the hexlower directory digest. Its value is the Directory message, serialized in canonical protobuf. We currently only populate this column.
In the future, we might want to introduce “bucketing”, essentially storing
all directories inserted via put_multiple_start in a batched form.
This will prevent looking up intermediate Directories, which are not
directly at the root, so rely on store composition.
Fields
instance_name: Stringclient: BigTableparams: BigtableParametersImplementations