Priority

Struct Priority 

pub struct Priority<DS> {
    instance_name: String,
    services: BTreeMap<Prio, DS>,
}
Holds references to many different directory services, each with an associated priority. Read requests try services sequentially, sorted by their priority, ascending. Any error in a service bubbles up. Write requests are not implemented.

Fields

instance_name: Stringservices: BTreeMap<Prio, DS>

The services, keyed by their priority.

Implementations

Source

impl<DS> Priority<DS>

pub fn new<I: IntoIterator<Item = (Prio, DS)>>( instance_name: String, iter: I, ) -> Priority<DS>

Construct from an iterator of priorities and services. Services with the same priority are converted to a race combinator.