enum DrainOrder {
RootToLeaves,
LeavesToRoot,
}Variants
RootToLeaves
Start with the root. Validates that newly received directories are already referenced from the root via existing directories.
LeavesToRoot
Each directory may only refer to directories already sent previously.