pub struct DirectoryGraph {
graph: DiGraph<Directory, ()>,
root_idx: NodeIndex,
}Expand description
This represents a full (and validated) graph of Directory nodes.
It can be constructed using DirectoryGraphBuilder, and is normally used to
receive in one or the other insertion order, validate, and then drain in
Leaves-To-Root order.
If you just want to validate an order without keeping the results,
RootToLeavesValidator or LeavesToRootValidator can be used.
Fields
graph: DiGraph<Directory, ()>root_idx: NodeIndexImplementations
Sourceimpl DirectoryGraph
impl DirectoryGraph
Sourcefn drain(self, order: DrainOrder) -> impl Iterator<Item = Directory>
fn drain(self, order: DrainOrder) -> impl Iterator<Item = Directory>
Drains the graph, returning node weights in the chosen DrainOrder.
Sourcepub fn drain_leaves_to_root(self) -> impl Iterator<Item = Directory>
pub fn drain_leaves_to_root(self) -> impl Iterator<Item = Directory>
Drains the graph in Leaves-To-Root Order.
Sourcepub fn drain_root_to_leaves(self) -> impl Iterator<Item = Directory>
pub fn drain_root_to_leaves(self) -> impl Iterator<Item = Directory>
Drains the graph in Root-To-Leaves Order.
Sourceimpl DirectoryGraph
impl DirectoryGraph
Sourcepub fn with_recalculated_sizes(self) -> Self
Available on crate feature compat-accept-bigger-sizes only.
pub fn with_recalculated_sizes(self) -> Self
compat-accept-bigger-sizes only.Returns a new DirectoryGraph for which all sizes have been recomputed. If there’s any change, it’ll cause referencing Directories to also have different digests. Data migration code to remove size calculation introduced in cl/12216 and cl/31479.