pub struct DirectoryGraphBuilder<OV> {
order_validator: OV,
graph: DiGraph<Option<Directory>, ()>,
digest_to_node_idx: HashMap<B3Digest, NodeIndex>,
}Expand description
Constructs a DirectoryGraph with a chosen insertion order.
After deciding on the insertion order (OV generic), and calling new (wants the expected root digest in the Root-To-Leaves case), different Directory can be passed to Self::try_insert. A Self::build consumes the builder, returning a validated DirectoryGraph, or an error. The resulting DirectoryGraph can be used to drain the graph in Leaves-To-Root or Root-To-Leaves order.
Fields
order_validator: OVStores the order validator for the chosen insertion order.
graph: DiGraph<Option<Directory>, ()>A directed graph, using Directory as node weight. Directories are Options to allow drawing edges to not-yet-received Directories in Root-To-Leaves order. Edges point from parents to children.
digest_to_node_idx: HashMap<B3Digest, NodeIndex>A lookup table from directory digest to node index. Used to lookup where to draw edges.
Implementations
Sourceimpl DirectoryGraphBuilder<LeavesToRoot>
impl DirectoryGraphBuilder<LeavesToRoot>
Sourcepub fn new() -> Self
pub fn new() -> Self
Constructs a new DirectoryGraphBuilder accepting directories in Leaves-To-Root order.
Sourceimpl DirectoryGraphBuilder<RootToLeaves>
impl DirectoryGraphBuilder<RootToLeaves>
Sourcepub fn new(root_digest: B3Digest) -> Self
pub fn new(root_digest: B3Digest) -> Self
Constructs a new DirectoryGraphBuilder accepting directories in Root-To-Leaves order. The expected root Directory needs to be passed as an argument, and is validated to match the one inserted on the first call to Self::try_insert.
Sourceimpl<OV> DirectoryGraphBuilder<OV>where
OV: OrderValidator,
impl<OV> DirectoryGraphBuilder<OV>where
OV: OrderValidator,
Sourcepub fn try_insert(&mut self, directory: Directory) -> Result<(), OrderingError>
pub fn try_insert(&mut self, directory: Directory) -> Result<(), OrderingError>
Accepts a directory if previously introduced, or returns an error if it’s unknown.
Sourcepub fn build(self) -> Result<DirectoryGraph, OrderingError>
pub fn build(self) -> Result<DirectoryGraph, OrderingError>
Ensures there’s no more directories missing, returns the validated DirectoryGraph.