pub struct LeavesToRoot {
accepted_directories: HashMap<B3Digest, RangeInclusive<u64>>,
pending_directories: HashSet<B3Digest>,
last_inserted_digest: Option<B3Digest>,
poison: bool,
}Expand description
A struct holding state while consuming a sequence of Directories in Leaves-To-Root order.
Validates that newly accepted directories only reference directories which have already been accepted before, and that the sizes attached alongside the pointers match the actual sizes. Commonly used when uploading a directory closure to a store.
Fields
accepted_directories: HashMap<B3Digest, RangeInclusive<u64>>compat-accept-bigger-sizes only.tracks inserted directories, and their sizes observed. size is tracked as a range, as this could be a closure with legacy sizes.
pending_directories: HashSet<B3Digest>tracks seen directories which are not yet referenced by parents. (root candidates)
last_inserted_digest: Option<B3Digest>Tracks the last received digest
poison: booltracks whether Self::finalize has been called, or an error has occurred while trying to accept.
Implementations
Sourceimpl LeavesToRoot
impl LeavesToRoot
pub fn new() -> Self
Sourcepub fn validate_stream<'s, S>(
directories: S,
) -> BoxStream<'s, Result<Directory, OrderingError>>
pub fn validate_stream<'s, S>( directories: S, ) -> BoxStream<'s, Result<Directory, OrderingError>>
This receives a stream of Directories, validating them to be in Leaves-To-Root order. If the order is correct, they are yielded wrapped in an Ok(). If not, we yield an error.