pub struct MockDirectoryPutter {
DirectoryPutter_expectations: MockDirectoryPutter_DirectoryPutter,
}Expand description
Provides a handle to put a closure of connected Directory elements.
The consumer can periodically call DirectoryPutter::put, starting from the leaves. Once the root is reached, DirectoryPutter::close can be called to retrieve the root digest (or an error).
DirectoryPutters might be created without a single DirectoryPutter::put, and then dropped without calling DirectoryPutter::close, for example when ingesting a path that ends up not pointing to a directory, but a single file or symlink.
Fields
DirectoryPutter_expectations: MockDirectoryPutter_DirectoryPutterImplementations
Sourceimpl MockDirectoryPutter
impl MockDirectoryPutter
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockDirectoryPutter
impl MockDirectoryPutter
Sourcepub fn expect_put(&mut self) -> &mut Expectation
pub fn expect_put(&mut self) -> &mut Expectation
Create an Expectation for mocking the put method
Sourcepub fn expect_close(&mut self) -> &mut Expectation
pub fn expect_close(&mut self) -> &mut Expectation
Create an Expectation for mocking the close method