MockDirectoryService

Struct MockDirectoryService 

pub struct MockDirectoryService {
    DirectoryService_expectations: MockDirectoryService_DirectoryService,
}
The base trait all Directory services need to implement. This is a simple get and put of Directory, returning their digest.

Fields

DirectoryService_expectations: MockDirectoryService_DirectoryService

Implementations

Source

impl MockDirectoryService

pub fn checkpoint(&mut self)

Validate that all current expectations for all methods have been satisfied, and discard them.

pub fn new() -> Self

Create a new mock object with no expectations.

This method will not be generated if the real struct already has a new method. However, it will be generated if the struct implements a trait with a new method. The trait’s new method can still be called like <MockX as TraitY>::new

Source

impl MockDirectoryService

pub fn expect_get(&mut self) -> &mut Expectation

Create an Expectation for mocking the get method

pub fn expect_put(&mut self) -> &mut Expectation

Create an Expectation for mocking the put method

pub fn expect_get_recursive(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_recursive method

pub fn expect_put_multiple_start(&mut self) -> &mut Expectation<'static>

Create an Expectation for mocking the put_multiple_start method