pub struct ObjectStoreDirectoryService {
instance_name: String,
object_store: Arc<dyn ObjectStore>,
base_path: Path,
}Expand description
Stores directory closures in an object store.
Notably, this makes use of the option to disallow accessing child directories except when
fetching them recursively via the top-level directory, since all batched writes
(using put_multiple_start) are stored in a single object.
Directories are stored in a length-delimited format with a 1MiB limit. The length field is a
u32 and the directories are stored in root-to-leaves topological order, the same way they will
be returned to the client in get_recursive.
Fields
instance_name: Stringobject_store: Arc<dyn ObjectStore>base_path: PathImplementations
Sourceimpl ObjectStoreDirectoryService
impl ObjectStoreDirectoryService
Sourcepub fn parse_url_opts<I, K, V>(url: &Url, options: I) -> Result<Self, Error>
pub fn parse_url_opts<I, K, V>(url: &Url, options: I) -> Result<Self, Error>
Constructs a new ObjectStoreDirectoryService from a Url supported by object_store. Any path suffix becomes the base path of the object store. additional options, the same as in object_store::parse_url_opts can be passed.
Sourcepub fn parse_url(url: &Url) -> Result<Self, Error>
pub fn parse_url(url: &Url) -> Result<Self, Error>
Like Self::parse_url_opts, except without the options.
pub fn new( instance_name: String, object_store: Arc<dyn ObjectStore>, base_path: Path, ) -> Self