pub trait RootNodes {
type Error: Error + Send + Sync + 'static;
// Required methods
fn get_by_basename<'life0, 'life1, 'async_trait>(
&'life0 self,
name: &'life1 PathComponent,
) -> Pin<Box<dyn Future<Output = Result<Option<Node>, Self::Error>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn list(
&self,
) -> BoxStream<'static, Result<(PathComponent, Node), Self::Error>>;
}Available on crate feature
fs only.Expand description
Provides an interface for looking up root nodes in snix-castore by given a lookup key (usually the basename), and optionally allow a listing.
Required Associated Types
Required Methods
Sourcefn get_by_basename<'life0, 'life1, 'async_trait>(
&'life0 self,
name: &'life1 PathComponent,
) -> Pin<Box<dyn Future<Output = Result<Option<Node>, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn get_by_basename<'life0, 'life1, 'async_trait>(
&'life0 self,
name: &'life1 PathComponent,
) -> Pin<Box<dyn Future<Output = Result<Option<Node>, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Looks up a root CA node based on the basename of the node in the root directory of the filesystem.