pub struct DirectoryEntry {
pub name: Bytes,
pub digest: Bytes,
pub size: u64,
}Expand description
A DirectoryEntry represents a directory.
Fields
name: BytesThe (base)name of the directory
digest: BytesThe blake3 digest of a Directory message.
size: u64Number of child elements in the Directory referred to by digest.
Child directory elements are counted twice for historical reasons.
Calculated by summing up the numbers of directories, files and
symlinks, and for each directory, its size field. Used for inode number
calculation.
This field is precisely as verifiable as any other Merkle tree edge.
Resolve digest, and you can compute it incrementally. Resolve the entire
tree, and you can fully compute it from scratch.
A credulous implementation won’t reject an excessive size, but this is
harmless: you’ll have some ordinals without nodes. Undersizing is obvious
and easy to reject: you won’t have an ordinal for some nodes.