ReferencePatternInner

Struct ReferencePatternInner 

pub struct ReferencePatternInner<P> {
    candidates: Vec<P>,
    longest_candidate: usize,
    searcher: Option<TwoByteWM>,
}
A searcher that incapsulates the candidates and the Wu-Manber searcher. This is separate from the scanner because we need to look for the same pattern in multiple outputs and don’t want to pay the price of constructing the searcher for each build output.

Fields

candidates: Vec<P>longest_candidate: usizesearcher: Option<TwoByteWM>