pub fn race_stream<'a, SVC, SVCS, F, Fut, S, T, E>(
services: SVCS,
f: F,
) -> impl Stream<Item = Result<T, Error<E>>> + 'aExpand description
Runs an operation returning a stream on all services.
The passed async function describes the operation to run on each service.
The returned Option<_> controls whether to ignore a response, such as an error,
or an empty stream (and continue with other backends) or return it.