pub struct Priority<DS> {
instance_name: String,
services: BTreeMap<Prio, DS>,
}Expand description
Holds references to many different directory services, each with an associated priority. Read requests try services sequentially, sorted by their priority, ascending. Any error in a service bubbles up. Write requests are not implemented.
Fields
instance_name: Stringservices: BTreeMap<Prio, DS>The services, keyed by their priority.
Implementations