pub trait OrderValidator {
// Required methods
fn try_accept(&mut self, directory: &Directory) -> Result<(), OrderingError>;
fn finalize(self) -> Result<(), OrderingError>;
}Expand description
Common trait implemented by both RootToLeaves and LeavesToRoot.
Required Methods
Sourcefn try_accept(&mut self, directory: &Directory) -> Result<(), OrderingError>
fn try_accept(&mut self, directory: &Directory) -> Result<(), OrderingError>
Succeeds if the directory is acceptable with the chosen insertion order.
Sourcefn finalize(self) -> Result<(), OrderingError>
fn finalize(self) -> Result<(), OrderingError>
Succeeds if the accepted directories are a full closure.